package com.jeeplus.test.program.configuration.projectList.service;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.utils.DictUtils;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.sys.utils.UserUtils;
import com.jeeplus.test.mould.service.SerialnumTplService;
import com.jeeplus.test.oss.domain.WorkAttachment;
import com.jeeplus.test.oss.mapper.OssServiceMapper;
import com.jeeplus.test.program.configuration.projectList.domain.*;
import com.jeeplus.test.program.configuration.projectList.mapper.*;
import com.jeeplus.test.program.configuration.projectList.service.dto.*;
import com.jeeplus.test.program.configuration.projectList.service.mapstruct.ProgramAuditAssessPeopleWrapper;
import com.jeeplus.test.program.configuration.projectList.service.mapstruct.ProgramAuditWrapper;
import com.jeeplus.test.proofread.domain.ProofreadDetail;
import com.jeeplus.test.proofread.service.ProofreadInfoService;
import com.jeeplus.test.proofread.service.dto.ProofreadInfoDto;
import com.jeeplus.test.workContract.domain.WorkContractInfo;
import com.jeeplus.test.workContract.mapper.WorkContractInfoMapper;
import com.jeeplus.test.workContract.service.WorkContractService;
import com.jeeplus.test.workContract.service.dto.WorkAttachmentDto;
import org.apache.commons.compress.utils.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class ProjectListService {

    @Resource
    private ProjectListMapper projectListMapper;
    @Resource
    private ProjectLinkMapper projectLinkMapper;
    @Resource
    private ProjectMemberMapper projectMemberMapper;
    @Resource
    private WorkContractInfoMapper workContractInfoMapper;
    @Resource
    private OssServiceMapper ossServiceMapper;

    @Resource
    private SerialnumTplService serialnumTplService;
    @Resource
    private WorkContractService workContractService;
    @Resource
    private ProgramAuditMapper programAuditMapper;
    @Resource
    private ProgramReportNoMapper programReportNoMapper;
    @Resource
    private ProgramAuditAssessPeopleMapper programAuditAssessPeopleMapper;
    @Resource
    private ProofreadInfoService proofreadInfoService;

    public String save(ProjectListDto dto) throws Exception{
        if (StringUtils.isNotEmpty(dto.getId())) {
            return update(dto);
        }
        return add(dto);
    }

    public String add(ProjectListDto dto) throws Exception{
        ProgramProjectListInfo info = new ProgramProjectListInfo();
        //获取当前登录人信息
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        // 保存项目管理列表主表信息
        BeanUtils.copyProperties(dto, info);
        String id = UUID.randomUUID().toString().replace("-", "");
        //合同编号生成
        String no = serialnumTplService.genSerialNum(userDTO.getCompanyDTO().getId(), ProjectListDto.BIZ_CODE);
        //项目立项号生成
        String approvalNo = serialnumTplService.genSerialNum(userDTO.getCompanyDTO().getId(), ProjectListDto.BIY_CODE);
        info.setId(id);
        info.setNo(no);
        info.setApprovalNo(approvalNo);
        info.setCreateBy(userDTO.getId());
        info.setCreateDate(new Date());
        info.setUpdateBy(userDTO.getId());
        info.setUpdateDate(new Date());
        info.setDelFlag(0);
        projectListMapper.insert(info);
        // 保存项目直接对接人信息
        if (CollectionUtils.isNotEmpty(dto.getLinks())) {
            for (ProgramProjectListLink link : dto.getLinks()) {
                link.setId(UUID.randomUUID().toString().replace("-", ""));
                link.setInfoId(id);
                link.setCreateBy(userDTO.getId());
                link.setCreateDate(new Date());
                link.setUpdateBy(userDTO.getId());
                link.setUpdateDate(new Date());
                link.setDelFlag(0);
                projectLinkMapper.insert(link);
            }
        }
        // 保存项目管理列表成员信息
        if (CollectionUtils.isNotEmpty(dto.getMembers())) {
            for (ProgramProjectListMember member : dto.getMembers()) {
                member.setId(UUID.randomUUID().toString().replace("-", ""));
                member.setInfoId(id);
                member.setCreateBy(userDTO.getId());
                member.setCreateDate(new Date());
                member.setUpdateBy(userDTO.getId());
                member.setUpdateDate(new Date());
                member.setDelFlag(0);
                projectMemberMapper.insert(member);
            }
        }
        // 保存附件信息
        if (CollectionUtils.isNotEmpty(dto.getFiles())) {
            workContractService.saveFiles(dto.getFiles(), userDTO, id);
        }
        // 三级校审添加
        ProgramAudit programAudit1 = new ProgramAudit();
        programAudit1.setAuditLevel("1");
        programAudit1.setProgramId(info.getId());
        programAudit1.setStatus("0");
        programAuditMapper.insert(programAudit1);
        ProgramAudit programAudit2 = new ProgramAudit();
        programAudit2.setAuditLevel("2");
        programAudit2.setProgramId(info.getId());
        programAudit2.setStatus("0");
        programAuditMapper.insert(programAudit2);
        ProgramAudit programAudit3 = new ProgramAudit();
        programAudit3.setAuditLevel("3");
        programAudit3.setProgramId(info.getId());
        programAudit3.setStatus("0");
        programAuditMapper.insert(programAudit3);
        return id;
    }

    public String saveFormThree(ProgramAuditDto programAuditDto) {
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        ProgramAudit programAudit = ProgramAuditWrapper.INSTANCE.toEntity(programAuditDto);
        if (StringUtils.isNotBlank(programAudit.getId())){
            programAuditMapper.updateById(programAudit);
        }else{
            programAuditMapper.insert(programAudit);
        }
        if (ObjectUtil.isNotEmpty(programAuditDto)) {
            //附件
            if (CollectionUtil.isNotEmpty(programAuditDto.getWorkAttachmentDtoList())) {
                List<String> ids = programAuditDto.getWorkAttachmentDtoList().stream().filter(item -> {
                    if (StringUtils.isNotBlank(item.getId())) {
                        return true;
                    }
                    return false;
                }).map(WorkAttachmentDto::getId).collect(Collectors.toList());
                if(CollectionUtil.isNotEmpty(ids)){
                    ossServiceMapper.delete(new QueryWrapper<WorkAttachment>().lambda()
                            .eq(WorkAttachment::getAttachmentId, programAudit.getId())
                            .notIn(WorkAttachment::getId,ids));
                }else{
                    ossServiceMapper.delete(new QueryWrapper<WorkAttachment>().lambda()
                            .eq(WorkAttachment::getAttachmentId, programAudit.getId()));
                }

                List<WorkAttachmentDto> dtoList = programAuditDto.getWorkAttachmentDtoList().stream().filter(item -> {
                    if (StringUtils.isNotBlank(item.getId())) {
                        return false;
                    }
                    return true;
                }).collect(Collectors.toList());

                workContractService.saveFilesNew(dtoList, userDTO, programAudit.getId(),"program");
            } else {
                ossServiceMapper.delete(new QueryWrapper<WorkAttachment>().lambda().eq(WorkAttachment::getAttachmentId, programAudit.getId()));
            }
            //专业评估人员
            if (CollectionUtil.isNotEmpty(programAuditDto.getProgramAuditAssessPeopleDtoList())) {
                programAuditAssessPeopleMapper.delete(new QueryWrapper<ProgramAuditAssessPeople>().lambda().eq(ProgramAuditAssessPeople::getAuditId,programAudit.getId()));
                programAuditDto.getProgramAuditAssessPeopleDtoList().stream().forEach(item->{
                    ProgramAuditAssessPeople programAuditAssessPeople = ProgramAuditAssessPeopleWrapper.INSTANCE.toEntity(item);
                    programAuditAssessPeopleMapper.insert(programAuditAssessPeople);
                });
            }else{
                programAuditAssessPeopleMapper.delete(new QueryWrapper<ProgramAuditAssessPeople>().lambda().eq(ProgramAuditAssessPeople::getAuditId,programAudit.getId()));
            }
        }
        return programAudit.getId();
    }

    public String update(ProjectListDto dto) {
        //获取当前登录人信息
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        // 修改项目管理列表主表信息
        ProgramProjectListInfo info = new ProgramProjectListInfo();
        BeanUtils.copyProperties(dto, info);
        info.setUpdateBy(userDTO.getId());
        info.setUpdateDate(new Date());
        info.setDelFlag(0);
        projectListMapper.updateById(info);
        // 修改联系人信息(先删除原有数据，再保存)
        if (CollectionUtils.isNotEmpty(dto.getLinks())) {
            projectLinkMapper.deleteByInfoId(dto.getId());
            for (ProgramProjectListLink link : dto.getLinks()) {
                link.setId(UUID.randomUUID().toString().replace("-", ""));
                link.setInfoId(dto.getId());
                link.setCreateBy(userDTO.getId());
                link.setCreateDate(new Date());
                link.setUpdateBy(userDTO.getId());
                link.setUpdateDate(new Date());
                link.setDelFlag(0);
                projectLinkMapper.insert(link);
            }
        }
        // 修改项目管理列表成员信息(先删除原有数据，再保存)
        if (CollectionUtils.isNotEmpty(dto.getMembers())) {
            projectMemberMapper.deleteByInfoId(dto.getId());
            for (ProgramProjectListMember member : dto.getMembers()) {
                member.setId(UUID.randomUUID().toString().replace("-", ""));
                member.setInfoId(dto.getId());
                member.setCreateBy(userDTO.getId());
                member.setCreateDate(new Date());
                member.setUpdateBy(userDTO.getId());
                member.setUpdateDate(new Date());
                member.setDelFlag(0);
                projectMemberMapper.insert(member);
            }
        }
        // 修改附件信息
        if (CollectionUtils.isNotEmpty(dto.getFiles())) {
            workContractService.updateFiles(dto.getFiles(), userDTO, dto.getId());
        }
        return dto.getId();
    }

    public ProjectListDto findById(String id) {
        ProjectListDto dto = new ProjectListDto();
        // 查询主表信息
        ProgramProjectListInfo info = projectListMapper.selectById(id);
        BeanUtils.copyProperties(info, dto);
        // 查询联系人列表
        LambdaQueryWrapper<ProgramProjectListLink> linkWrapper = new LambdaQueryWrapper<>();
        linkWrapper.eq(ProgramProjectListLink::getInfoId, id);
        linkWrapper.eq(ProgramProjectListLink::getDelFlag, 0);
        List<ProgramProjectListLink> links = projectLinkMapper.selectList(linkWrapper);
        if (CollectionUtils.isNotEmpty(links)) {
            dto.setLinks(links);
        }
        // 查询成员列表
        LambdaQueryWrapper<ProgramProjectListMember> memberWrapper = new LambdaQueryWrapper<>();
        memberWrapper.eq(ProgramProjectListMember::getInfoId, id);
        memberWrapper.eq(ProgramProjectListMember::getDelFlag, 0);
        List<ProgramProjectListMember> members = projectMemberMapper.selectList(memberWrapper);
        if (CollectionUtils.isNotEmpty(members)) {
            dto.setMembers(members);
        }
        // 查询附件信息
        List<WorkAttachmentDto> files = workContractInfoMapper.findDtos(id);
        if (CollectionUtils.isNotEmpty(files)) {
            for (WorkAttachmentDto i : files) {
                i.setCreateBy(UserUtils.get(i.getBy()));
            }
            dto.setFiles(files);
        }
        return dto;
    }

    public ProgramAuditDto findByIdAudit(String id){
        ProgramAuditDto byIdAudit = programAuditMapper.findByIdAudit(id);
        // 查询附件信息
        List<WorkAttachmentDto> files = workContractInfoMapper.findDtos(id);
        if (CollectionUtils.isNotEmpty(files)) {
            for (WorkAttachmentDto i : files) {
                i.setCreateBy(UserUtils.get(i.getBy()));
            }
            byIdAudit.setWorkAttachmentDtoList(files);
        }
        return byIdAudit;
    }

    public String deleteById(String id) {
        projectListMapper.deleteById(id);
        projectLinkMapper.deleteByInfoId(id);
        projectMemberMapper.deleteByInfoId(id);
        // 附件删除
        LambdaQueryWrapper<WorkAttachment> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(WorkAttachment::getAttachmentId, id);
        ossServiceMapper.delete(wrapper);
        return "操作成功";
    }

    public IPage<WorkContractInfo> findContractPageList(ContractDto dto, Page<WorkContractInfo> page) {
        return projectListMapper.findContractPageList(page, dto);
    }

    public String updateStatusById(ProjectListDto dto) {
        projectListMapper.updateStatusById(dto.getId(), dto.getStatus());
        return "操作成功";
    }

    public String updateStatusByAuditId(ProjectListDto dto) {
        ProgramAudit programAudit = new ProgramAudit();
        programAudit.setId(dto.getId());
        programAudit.setStatus(dto.getStatus());
        programAuditMapper.update(programAudit,new QueryWrapper<ProgramAudit>().lambda().eq(ProgramAudit::getId,programAudit.getId()));
        return "操作成功";
    }

    public IPage<ProgramProjectListInfo> list(Page<ProgramProjectListInfo> page, ProgramProjectListInfo info) throws Exception{
        QueryWrapper<ProgramProjectListInfo> wrapper = QueryWrapperGenerator.buildQueryCondition(info, ProgramProjectListInfo.class);
        wrapper.eq("a.del_flag", "0");
        if (info.getCreateDates() != null) {
            wrapper.between("a.create_date", info.getCreateDates()[0], info.getCreateDates()[1]);
        }
        IPage<ProgramProjectListInfo> pageList = projectListMapper.findPageList(page, wrapper);
        pageList.getRecords().stream().forEach(item ->{
            String isInvoice = projectListMapper.selectInvoiceFlag(item.getId());
            item.setIsInvoice(isInvoice);
        });
        return pageList;
    }

    public List<ExportFileDto> exportList(ProgramProjectListInfo info) throws Exception{
        QueryWrapper<ProgramProjectListInfo> wrapper = QueryWrapperGenerator.buildQueryCondition(info, ProgramProjectListInfo.class);
        wrapper.eq("a.del_flag", "0");
        if (info.getCreateDates() != null) {
            wrapper.between("a.create_date", info.getCreateDates()[0], info.getCreateDates()[1]);
        }
        List<ExportFileDto> list = projectListMapper.findList(wrapper);
        // 状态值处理
        if (CollectionUtils.isNotEmpty(list)) {
            for(ExportFileDto i : list) {
                if ("0".equals(i.getStatus())) {
                    i.setStatus("未登记");
                }
                if ("1".equals(i.getStatus())) {
                    i.setStatus("暂存");
                }
                if ("2".equals(i.getStatus())) {
                    i.setStatus("登记中");
                }
                if ("3".equals(i.getStatus())) {
                    i.setStatus("撤回");
                }
                if ("4".equals(i.getStatus())) {
                    i.setStatus("驳回");
                }
                if ("5".equals(i.getStatus())) {
                    i.setStatus("登记完成");
                }
            }
        }
        return list;
    }

    public String saveReportNo(String id) throws Exception{
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        ProgramProjectListInfo programProjectListInfo = projectListMapper.selectById(id);
        String reportNo = "";
        if(ObjectUtil.isNotEmpty(programProjectListInfo)){
            if(StringUtils.isNotBlank(programProjectListInfo.getReportType())){
                if (programProjectListInfo.getReportType().equals("1")){
                    reportNo = serialnumTplService.genSerialNum(userDTO.getCompanyDTO().getId(), ProgramReportNoDto.BIZ_CODE);
                } else if (programProjectListInfo.getReportType().equals("2")) {
                    reportNo = serialnumTplService.genSerialNum(userDTO.getCompanyDTO().getId(), ProgramReportNoDto.BIZ_CODE_);
                }
                ProgramReportNo programReportNo = new ProgramReportNo();
                programReportNo.setProgramId(id);
                programReportNo.setReportNo(reportNo);
                programReportNoMapper.insert(programReportNo);
            }
        }
        return reportNo;
    }

    /**
     * 查询校审数据信息并导出文档
     * @param info
     * @return
     */
    public Map<String,Object> getAuditInfoMap(ProgramProjectListInfo info){
        Map data = new HashMap();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年 MM月 dd日");

        //查询项目信息
        ProjectListDto projectDto = findById(info.getId());

        //查询校审信息
        ProgramAuditDto auditDto =null;
        if(StringUtils.isNotBlank(info.getAuditId1())){
            auditDto = findByIdAudit(info.getAuditId1());
        }else if(StringUtils.isNotBlank(info.getAuditId2())) {
            auditDto = findByIdAudit(info.getAuditId2());
        }else if(StringUtils.isNotBlank(info.getAuditId3())) {
            auditDto = findByIdAudit(info.getAuditId3());
        }
        //项目名称
        data.put("projectName",projectDto.getName());
        //评估基准日
        Date assessmentDate=projectDto.getAssessmentDate();
        if(null == assessmentDate){
            data.put("assessBaseMessage","");
        }else{
            String str = sdf.format(assessmentDate);
            data.put("assessBaseMessage",str);
        }
        //项目负责人
        if(StringUtils.isBlank(projectDto.getProjectManager())){
            data.put("projectMaster","");
        }else{
            data.put("projectMaster",UserUtils.get(projectDto.getProjectManager()).getName());
        }
        //如果存在审核意见则进行处理
        if(null != auditDto){
            //专业评估人员
            List<ProgramAuditAssessPeopleDto> programAuditAssessPeopleDtoList = auditDto.getProgramAuditAssessPeopleDtoList();
            List<String> appraiserList = Lists.newArrayList();
            for (ProgramAuditAssessPeopleDto assessPeopleDto:programAuditAssessPeopleDtoList) {
                appraiserList.add(UserUtils.get(assessPeopleDto.getAssessPeople()).getName());
            }
            data.put("appraisers",String.join(",",appraiserList));

            //项目审核人
            data.put("projectauditor",UserUtils.get(auditDto.getAuditPeople()).getName());
            //明细表
            data.put("detailedStatement",disposeAuditDetails(auditDto.getDetailOpinion()));
            //评估报告
            data.put("assessmentReport",disposeAuditDetails(auditDto.getReportOpinion()));
            //技术说明
            data.put("technicalDescription",disposeAuditDetails(auditDto.getRemarksOpinion()));
            //工作底稿
            data.put("workingPaper",disposeAuditDetails(auditDto.getWorkOpinion()));
            //保留意见
            data.put("qualifiedOpinion",auditDto.getRetainOpinion());
            //执行人
            data.put("executor",UserUtils.get(auditDto.getCreateBy().getId()).getName());

            Date auditDate=projectDto.getAssessmentDate();
            if(null == auditDate){
                //执行人时间
                data.put("executorDate","");
                //审核人时间
                data.put("auditorDate","");
            }else{
                String str = sdf.format(auditDate);
                //执行人时间
                data.put("executorDate",str);
                //审核人时间
                data.put("auditorDate",str);
            }

            //未修改意见
            data.put("notModifiedOpinion",auditDto.getChangeOpinion());
            //审核人
            data.put("auditor",UserUtils.get(auditDto.getAuditPeople()).getName());

        }
        return data;
    }

    /**
     * 审核内容处理
     * @param auditDetails
     * @return
     */
    private String disposeAuditDetails(String auditDetails){
        if(StringUtils.isNotBlank(auditDetails)){
            auditDetails = auditDetails.replaceAll("<p>","");
            auditDetails = auditDetails.replaceAll("</p>","<w:br/>");
            auditDetails = auditDetails.replaceAll("<br>","");
        }
        return auditDetails;
    }



    /**
     * 查询校审数据信息并导出文档
     * @param info
     * @return
     */
    public Map<String,Object> getProofreadAuditMap(ProgramProjectListInfo info){
        Map data = new HashMap();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年 MM月 dd日");

        //查询项目信息
        ProjectListDto projectDto = findById(info.getId());

        //查询自校数据信息信息
        ProofreadInfoDto proofreadInfoDto = proofreadInfoService.findById(info.getId(),"1");

        /**
         * 自校明细表信息
         */
        List<ProofreadDetail> details = proofreadInfoDto.getDetails();
        List<ProofreadDetail> detailedStatementList = Lists.newArrayList();
        List<ProofreadDetail> assessmentInstructions1List = Lists.newArrayList();
        List<ProofreadDetail> assessmentInstructions2List = Lists.newArrayList();
        List<ProofreadDetail> assessmentInstructions3List = Lists.newArrayList();
        List<ProofreadDetail> assessmentInstructions4List = Lists.newArrayList();
        List<ProofreadDetail> assessmentInstructions5List = Lists.newArrayList();
        List<ProofreadDetail> assessmentReportList = Lists.newArrayList();
        Integer detailedStatement = 0;
        Integer assessmentInstructions1 = 0;
        Integer assessmentInstructions2 = 0;
        Integer assessmentInstructions3 = 0;
        Integer assessmentInstructions4 = 0;
        Integer assessmentInstructions5 = 0;
        Integer assessmentReport = 0;

        for (ProofreadDetail item :details) {
            if(item.getSort().startsWith("1010")){
                detailedStatement ++ ;
                item.setSerialNumber(detailedStatement);
                detailedStatementList.add(item);
            }else if(item.getSort().startsWith("2010")){
                assessmentInstructions1 ++ ;
                item.setSerialNumber(assessmentInstructions1);
                assessmentInstructions1List.add(item);
            }else if(item.getSort().startsWith("2020")){
                assessmentInstructions2 ++ ;
                item.setSerialNumber(assessmentInstructions2);
                assessmentInstructions2List.add(item);
            }else if(item.getSort().startsWith("2030")){
                assessmentInstructions3 ++ ;
                item.setSerialNumber(assessmentInstructions3);
                assessmentInstructions3List.add(item);
            }else if(item.getSort().startsWith("2040")){
                assessmentInstructions4 ++ ;
                item.setSerialNumber(assessmentInstructions4);
                assessmentInstructions4List.add(item);
            }else if(item.getSort().startsWith("2050")){
                assessmentInstructions5 ++ ;
                item.setSerialNumber(assessmentInstructions5);
                assessmentInstructions5List.add(item);
            }else if(item.getSort().startsWith("2060")){

            }else if(item.getSort().startsWith("30")){
                assessmentReport ++ ;
                item.setSerialNumber(assessmentReport);
                assessmentReportList.add(item);
            }

        }
        data.put("detailedStatementList",detailedStatementList);
        data.put("assessmentInstructions1List",assessmentInstructions1List);
        data.put("assessmentInstructions2List",assessmentInstructions2List);
        data.put("assessmentInstructions3List",assessmentInstructions3List);
        data.put("assessmentInstructions4List",assessmentInstructions4List);
        data.put("assessmentInstructions5List",assessmentInstructions5List);
        data.put("assessmentReportList",assessmentReportList);


        //项目名称
        data.put("projectName",projectDto.getName());
        //评估基准日
        Date assessmentDate=projectDto.getAssessmentDate();
        if(null == assessmentDate){
            data.put("assessBaseMessage","");
        }else{
            String str = sdf.format(assessmentDate);
            data.put("assessBaseMessage",str);
        }
        //项目负责人
        if(StringUtils.isBlank(projectDto.getProjectManager())){
            data.put("projectMaster","");
        }else{
            data.put("projectMaster",UserUtils.get(projectDto.getProjectManager()).getName());
        }

        //项目审核人
        data.put("projectauditor","");
        //项目审核时间
        data.put("projectAuditDate","");
        //审核人员签字
        data.put("auditPersonnel","");
        //项目审核时间
        data.put("auditDate","");
        //改正人员签字
        data.put("correctPersonnel",UserUtils.get(proofreadInfoDto.getUpdateBy()).getName());
        //项目审核时间
        data.put("correctDate","");
        //保留意见
        data.put("qualifiedOpinion",proofreadInfoDto.getReservations());
        //未修改意见
        data.put("notModifiedOpinion",proofreadInfoDto.getUnmodifiedComments());
        //执行人
        data.put("executor",UserUtils.get(proofreadInfoDto.getUpdateBy()).getName());
        //执行时间
        Date executorDate=proofreadInfoDto.getUpdateDate();
        if(null == executorDate){
            data.put("executorDate","");
        }else{
            String str = sdf.format(executorDate);
            data.put("executorDate",str);
        }

        return data;
    }



    /**
     * 查询评估报告装订后浏览审核记录表并导出文档
     * @param info
     * @return
     */
    public Map<String,Object> getAuditRecordFormAfterBindingMap(ProgramProjectListInfo info){
        Map data = new HashMap();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年 MM月 dd日");

        //查询项目信息
        ProjectListDto projectDto = findById(info.getId());

        //查询自校数据信息信息
        ProofreadInfoDto proofreadInfoDto = proofreadInfoService.findById(info.getId(),"2");

        /**
         * 自校明细表信息
         */

        List<ProofreadDetail> details = proofreadInfoDto.getDetails();
        List<ProofreadDetail> assessmentList = Lists.newArrayList();
        List<ProofreadDetail> assessmentReportList = Lists.newArrayList();
        List<ProofreadDetail> assessmentExplainList = Lists.newArrayList();
        List<ProofreadDetail> assessmentDetailList = Lists.newArrayList();
        Integer assessment = 0;
        Integer assessmentReport = 0;
        Integer assessmentExplain = 0;
        Integer assessmentDetail = 0;

        for (ProofreadDetail item :details) {
            if(item.getSort().startsWith("40")){
                assessment ++ ;
                item.setSerialNumber(assessment);
                assessmentList.add(item);
            }else if(item.getSort().startsWith("50")){
                assessmentReport ++ ;
                item.setSerialNumber(assessmentReport);
                assessmentReportList.add(item);
            }else if(item.getSort().startsWith("60")){
                assessmentExplain ++ ;
                item.setSerialNumber(assessmentExplain);
                assessmentExplainList.add(item);
            }else if(item.getSort().startsWith("70")){
                assessmentDetail ++ ;
                item.setSerialNumber(assessmentDetail);
                assessmentDetailList.add(item);
            }

        }

        data.put("assessmentList",assessmentList);
        data.put("assessmentReportList",assessmentReportList);
        data.put("assessmentExplainList",assessmentExplainList);
        data.put("assessmentDetailList",assessmentDetailList);


        //项目名称
        data.put("projectName",projectDto.getName());
        //评估基准日
        Date assessmentDate=projectDto.getAssessmentDate();
        if(null == assessmentDate){
            data.put("assessBaseMessage","");
        }else{
            String str = sdf.format(assessmentDate);
            data.put("assessBaseMessage",str);
        }
        //项目负责人
        if(StringUtils.isBlank(projectDto.getProjectManager())){
            data.put("projectMaster","");
        }else{
            data.put("projectMaster",UserUtils.get(projectDto.getProjectManager()).getName());
        }

        //项目审核人
        data.put("projectauditor","");
        //项目审核时间
        data.put("projectAuditDate","");
        //审核人员签字
        data.put("auditPersonnel","");
        //项目审核时间
        data.put("auditDate","");
        //改正人员签字
        data.put("correctPersonnel",UserUtils.get(proofreadInfoDto.getUpdateBy()).getName());
        //项目审核时间
        data.put("correctDate","");
        //保留意见
        data.put("qualifiedOpinion",proofreadInfoDto.getReservations());
        //未修改意见
        data.put("notModifiedOpinion",proofreadInfoDto.getUnmodifiedComments());
        //执行人
        data.put("executor",UserUtils.get(proofreadInfoDto.getUpdateBy()).getName());
        //执行时间
        Date executorDate=proofreadInfoDto.getUpdateDate();
        if(null == executorDate){
            data.put("executorDate","");
        }else{
            String str = sdf.format(executorDate);
            data.put("executorDate",str);
        }

        return data;
    }
}
